@@ -8,7 +8,7 @@
 #
 #  An instance of class HttpDaemonRspResponse, which extends the
 #  @see "RspResponse" class, is a buffer for output (response) sent to an
-#  @see "HttpDaemon".  It provides a method \code{write()} for writing
+#  @see "HttpDaemon".  It provides a method \code{writeResponse()} for writing
 #  output and a method \code{flush()} for flush the written output to
 #  the HTTP daemon.
 # }
@@ -62,7 +62,7 @@ setConstructorS3("HttpDaemonRspResponse", function(httpDaemon=NULL, ...) {
 })
 
 
-setMethodS3("write", "HttpDaemonRspResponse", function(this, ..., collapse="", sep="") {
+setMethodS3("writeResponse", "HttpDaemonRspResponse", function(this, ..., collapse="", sep="") {
   version <- getOption("R.rsp/HttpDaemon/RspVersion", "0.1.0");
   # Argment 'version':
   if (!is.element(version, c("0.1.0", "1.0.0"))) {
@@ -100,22 +100,3 @@ setMethodS3("flush", "HttpDaemonRspResponse", function(con) {
 
   invisible(len);
 }, appendVarArgs=FALSE)
-
-
-
-##############################################################################
-# HISTORY:
-# 2013-05-23
-# o Now write() for HttpDaemonRspResponse supports the new RSP engine too.
-# 2011-03-15
-# o BUG FIX: write() for RspResponse classes would ignore arguments
-#   'collapse' and 'sep'.
-# 2006-07-04
-# o Renamed from HttpDaemonResponse to HttpDaemonRspResponse.
-# 2006-01-21
-# o Made the class independent of the Tcl source code.  Now it is simply
-#   flushing output to writeResponse() of the HttpDaemon object.
-# o Added Rdoc comments.
-# 2005-11-30
-# o Created.
-##############################################################################
