@@ -26,7 +26,7 @@
 # }
 #*/#########################################################################
 setMethodS3("toR", "RspString", function(object, envir=parent.frame(), ...) {
-  expr <- parse(object, preprocess=TRUE, envir=envir, ...);
+  expr <- parseExpression(object, preprocess=TRUE, envir=envir, ...);
   toR(expr, ...);
 }, protected=TRUE) # toR()
 
@@ -62,13 +62,3 @@ setMethodS3("evaluate", "RspString", function(object, envir=parent.frame(), ...)
   rCode <- toR(object, ...);
   process(rCode, envir=envir, ...);
 }, createGeneric=FALSE)
-
-
-
-##############################################################################
-# HISTORY:
-# 2013-02-11
-# o Added Rdoc help.
-# 2013-02-09
-# o Created.
-##############################################################################
