@@ -50,7 +50,7 @@ setMethodS3("rclean", "default", function(..., file=NULL, path=NULL, envir=paren
       file <- file.path(path, file);
     }
     if (!isUrl(file)) {
-      file <- Arguments$getReadablePathname(file, absolutePath=TRUE);
+      file <- Arguments$getReadablePathname(file, absolute=TRUE);
     }
   }
 
@@ -128,11 +128,11 @@ setMethodS3("rclean", "RspString", function(object, envir=parent.frame(), args="
       print(verbose, ll);
     }
   }
-  expr <- parse(object, envir=envir, ..., verbose=verbose);
-  verbose && print(verbose, expr);
+  doc <- parseDocument(object, envir=envir, ..., verbose=verbose);
+  verbose && print(verbose, doc);
   verbose && exit(verbose);
 
-  res <- rclean(expr, envir=envir, args=NULL, ..., verbose=verbose);
+  res <- rclean(doc, envir=envir, args=NULL, ..., verbose=verbose);
 
   verbose && exit(verbose);
 
@@ -161,13 +161,3 @@ setMethodS3("rclean", "RspDocument", function(object, envir=parent.frame(), ...,
 
   s;
 }) # rclean()
-
-
-##############################################################################
-# HISTORY:
-# 2014-01-26
-# o CLEANUP: Now R.oo::ll() is only called if 'verbose' is enabled, because
-#   calling ll() still triggers attachment of R.oo as of R.oo (>= 1.17.0).
-# 2013-03-14
-# o Created from rscript.R.
-##############################################################################
